@@ -23,11 +23,7 @@
 #include <config-kglobalaccel.h>
 
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 #endif
 
 org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QString &componentUnique, bool remember = false)
@@ -125,12 +121,6 @@ org::kde::KGlobalAccel *KGlobalAccelPrivate::iface()
             }
         }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 90)
-        q->connect(m_iface, &org::kde::KGlobalAccel::yourShortcutGotChanged, q, [this](const QStringList &actionId, const QList<int> &newKeys) {
-            shortcutGotChanged(actionId, newKeys);
-        });
-#endif
-
         q->connect(m_iface, &org::kde::KGlobalAccel::yourShortcutsChanged, q, [this](const QStringList &actionId, const QList<QKeySequence> &newKeys) {
             shortcutsChanged(actionId, newKeys);
         });
@@ -155,15 +145,6 @@ KGlobalAccel::~KGlobalAccel()
     delete d;
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 102)
-void KGlobalAccel::activateGlobalShortcutContext(const QString &contextUnique, const QString &contextFriendly, const QString &programName)
-{
-    Q_UNUSED(contextFriendly);
-    // TODO: provide contextFriendly
-    self()->d->iface()->activateGlobalShortcutContext(programName, contextUnique);
-}
-#endif
-
 // static
 bool KGlobalAccel::cleanComponent(const QString &componentUnique)
 {
@@ -186,25 +167,11 @@ bool KGlobalAccel::isComponentActive(const QString &componentUnique)
     return component->isActive();
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 4)
-bool KGlobalAccel::isEnabled() const
-{
-    return d->enabled;
-}
-#endif
-
 org::kde::kglobalaccel::Component *KGlobalAccel::getComponent(const QString &componentUnique)
 {
     return d->getComponent(componentUnique);
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 4)
-void KGlobalAccel::setEnabled(bool enabled)
-{
-    d->enabled = enabled;
-}
-#endif
-
 class KGlobalAccelSingleton
 {
 public:
@@ -394,11 +361,7 @@ QList<int> KGlobalAccelPrivate::intListFromShortcut(const QList<QKeySequence> &c
 {
     QList<int> ret;
     for (const QKeySequence &sequence : cut) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         ret.append(sequence[0].toCombined());
-#else
-        ret.append(sequence[0]);
-#endif
     }
     while (!ret.isEmpty() && ret.last() == 0) {
         ret.removeLast();
@@ -511,20 +474,6 @@ void KGlobalAccelPrivate::invokeDeactivate(const QString &componentUnique, const
     Q_EMIT q->globalShortcutActiveChanged(action, false);
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 90)
-void KGlobalAccelPrivate::shortcutGotChanged(const QStringList &actionId, const QList<int> &keys)
-{
-    QAction *action = nameToAction.value(actionId.at(KGlobalAccel::ActionUnique));
-    if (!action) {
-        return;
-    }
-
-    const QList<QKeySequence> shortcuts = shortcutFromIntList(keys);
-    actionShortcuts.insert(action, shortcuts);
-    Q_EMIT q->globalShortcutChanged(action, keys.isEmpty() ? QKeySequence() : shortcuts.first());
-}
-#endif
-
 void KGlobalAccelPrivate::shortcutsChanged(const QStringList &actionId, const QList<QKeySequence> &keys)
 {
     QAction *action = nameToAction.value(actionId.at(KGlobalAccel::ActionUnique));
@@ -565,35 +514,6 @@ void KGlobalAccelPrivate::reRegisterAll()
     }
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
-QList<QStringList> KGlobalAccel::allMainComponents()
-{
-    return d->iface()->allMainComponents();
-}
-#endif
-
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
-QList<QStringList> KGlobalAccel::allActionsForComponent(const QStringList &actionId)
-{
-    return d->iface()->allActionsForComponent(actionId);
-}
-#endif
-
-// static
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
-QStringList KGlobalAccel::findActionNameSystemwide(const QKeySequence &seq)
-{
-    return self()->d->iface()->actionList(seq);
-}
-#endif
-
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 90)
-QList<KGlobalShortcutInfo> KGlobalAccel::getGlobalShortcutsByKey(const QKeySequence &seq)
-{
-    return globalShortcutsByKey(seq);
-}
-#endif
-
 QList<KGlobalShortcutInfo> KGlobalAccel::globalShortcutsByKey(const QKeySequence &seq, MatchType type)
 {
     return self()->d->iface()->globalShortcutsByKey(seq, type);
@@ -604,29 +524,6 @@ bool KGlobalAccel::isGlobalShortcutAvailable(const QKeySequence &seq, const QStr
     return self()->d->iface()->globalShortcutAvailable(seq, comp);
 }
 
-// static
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
-bool KGlobalAccel::promptStealShortcutSystemwide(QWidget *parent, const QStringList &actionIdentifier, const QKeySequence &seq)
-{
-    if (actionIdentifier.size() < 4) {
-        return false;
-    }
-    QString title = tr("Conflict with Global Shortcut");
-    QString message = tr("The '%1' key combination has already been allocated "
-                         "to the global action \"%2\" in %3.\n"
-                         "Do you want to reassign it from that action to the current one?")
-                          .arg(seq.toString(), actionIdentifier.at(KGlobalAccel::ActionFriendly), actionIdentifier.at(KGlobalAccel::ComponentFriendly));
-
-    QMessageBox box(parent);
-    box.setWindowTitle(title);
-    box.setText(message);
-    box.addButton(QMessageBox::Ok)->setText(tr("Reassign"));
-    box.addButton(QMessageBox::Cancel);
-
-    return box.exec() == QMessageBox::Ok;
-}
-#endif
-
 // static
 bool KGlobalAccel::promptStealShortcutSystemwide(QWidget *parent, const QList<KGlobalShortcutInfo> &shortcuts, const QKeySequence &seq)
 {
@@ -684,11 +581,7 @@ bool checkGarbageKeycode(const QList<QKeySequence> &shortcut)
     // at the moment (~mid 2008) Multimedia PlayPause is one of those keys.
     for (const QKeySequence &sequence : shortcut) {
         for (int i = 0; i < 4; i++) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             if (sequence[i].toCombined() == -1) {
-#else
-            if (sequence[i] == -1) {
-#endif
                 qWarning() << "Encountered garbage keycode (keycode = -1) in input, not doing anything.";
                 return true;
             }
@@ -759,13 +652,6 @@ bool KGlobalAccel::hasShortcut(const QAction *action) const
     return d->actionShortcuts.contains(action) || d->actionDefaultShortcuts.contains(action);
 }
 
-#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 9)
-bool KGlobalAccel::eventFilter(QObject *watched, QEvent *event)
-{
-    return QObject::eventFilter(watched, event);
-}
-#endif
-
 bool KGlobalAccel::setGlobalShortcut(QAction *action, const QList<QKeySequence> &shortcut)
 {
     KGlobalAccel *g = KGlobalAccel::self();
